@@ -3,6 +3,14 @@
 
 #include <stdlib.h>
 
+#ifndef _ANSI_ARGS_
+#ifdef __STDC__
+#define _ANSI_ARGS_(x) x
+#else
+#define _ANSI_ARGS_(x) ()
+#endif
+#endif
+
 #define STRING_HEADER_FORMAT	"%4.4d"
 #define CB_STRING_HEADER	(5)
 /*
@@ -56,16 +64,15 @@ struct message_header * guiParseMsg1();
 extern pid_t parent;
 
 struct connection_state *
-sock_connect_to_name( char *host_id, int name, int async );
+sock_connect_to_name();
 void sock_close_connection( );
-int sock_read_str(int connection, char *buffer, int max_len);
+int sock_read_str();
 
-guiMsg *guiParseMsg(struct connection_state *sfd);
-void guiFreeMsg(guiMsg *pgmsg);
+guiMsg *guiParseMsg();
+void guiFreeMsg();
 
 void
-guiCreateThenBindCallback(int idLispObject, int iSlot
-			  , char *szTclObject, char *szModifier, char *arglist);
-int guiBindCallback(char *szNameCmdProc, char *szTclObject, char *szModifier,char* arglist);
+guiCreateThenBindCallback();
+int guiBindCallback();
 
 #endif
