@@ -31,10 +31,8 @@ object fSallocate_contiguous_pages();
 object fSallocate_relocatable_pages();
 /*  array.c  */
 enum aelttype Iarray_element_type();
-object aref();
-object aset();
-object aref1();
-object aset1();
+object fSaref1();
+object fSaset1();
 EXTER object sLarray_dimension_limit;
 EXTER object sLarray_total_size_limit;
 object fSmake_array1();
@@ -443,6 +441,7 @@ EXTER object siSsharp_comma;
 EXTER bool escape_flag;
 EXTER object delimiting_char;
 EXTER bool detect_eos_flag;
+EXTER object read_byte1(); 
 /* bool in_list_flag; */
 EXTER bool dot_flag;
 EXTER bool preserving_whitespace_flag;
