@@ -37,12 +37,12 @@ void isetq_fix();
 #define SETQ_IO(var,alloc,val) {object _xx =(val) ; \
 			      int _n = obj_replace_copy1(_xx,var); \
 			    if(_n) var = obj_replace_copy2(_xx,alloca(_n));}
-#define IDECL(a,b,c) ulong b[4];a =(b[0]=0x1010000 +4,b) ; object c
+#define IDECL(a,b,c) our_ulong b[4];a =(b[0]=0x1010000 +4,b) ; object c
 #else
 GEN setq_io(),setq_ii();
 #define SETQ_IO(x,alloc,val)   (x)=setq_io(x,&alloc,val)
 #define SETQ_II(x,alloc,val)   (x)=setq_ii(x,&alloc,val)
-#define IDECL(a,b,c) ulong b[4];a =(b[0]=0x1010000 +4,b);object c
+#define IDECL(a,b,c) our_ulong b[4];a =(b[0]=0x1010000 +4,b);object c
 #endif
 
 #define	cclosure_call	funcall
