@@ -34,16 +34,11 @@ typedef struct invocation_history {
 	object	*ihs_base;
 } *ihs_ptr;
 
-#define	IHSSIZE		1024
-#define	IHSGETA		32
+EXTER ihs_ptr ihs_org;
 
-struct invocation_history ihs_stack[IHSSIZE + (STACK_OVER +1) * IHSGETA];
+EXTER ihs_ptr ihs_limit;
 
-ihs_ptr ihs_org;
-
-ihs_ptr ihs_limit;
-
-ihs_ptr ihs_top;
+EXTER ihs_ptr ihs_top;
 
 #define	ihs_check  \
 	if (ihs_top >= ihs_limit)  \
@@ -52,6 +47,9 @@ ihs_ptr ihs_top;
 #define ihs_push(function)  \
 	(++ihs_top)->ihs_function = (function);  \
 	ihs_top->ihs_base = vs_base
+#define ihs_push_base(function,base)  \
+	(++ihs_top)->ihs_function = (function);  \
+	ihs_top->ihs_base = base
 
 #define ihs_pop() 	(ihs_top--)
 
@@ -77,11 +75,13 @@ enum fr_class {
 	FRS_PROTECT                	/* for protect-all */
 };
 
+EXTER int in_signal_handler;
 struct frame {
 	jmp_buf		frs_jmpbuf;
 	object		*frs_lex;
 	bds_ptr		frs_bds_top;
-	enum fr_class	frs_class;
+	char 	frs_class;
+	char frs_in_signal_handler;
 	object		frs_val;
 	ihs_ptr		frs_ihs;
 };
@@ -104,35 +104,36 @@ PROTECT   |               NIL                    |
 ----------------------------------------------------------------
 */
 
-#define FRSSIZE		1024
-#define	FRSGETA		16
 
-struct frame frame_stack[FRSSIZE + (STACK_OVER +1) * FRSGETA];
+EXTER frame_ptr frs_org;
 
-frame_ptr frs_org;
+EXTER frame_ptr frs_limit;
 
-frame_ptr frs_limit;
+EXTER frame_ptr frs_top;		/* frame stack top */
 
-frame_ptr frs_top;		/* frame stack top */
 
 #define frs_push(class, val)  \
-	if (++frs_top >= frs_limit)  \
+   do { frame_ptr _frs_top = frs_top +1; \
+	if (_frs_top >= frs_limit)  \
 		frs_overflow();  \
-	frs_top->frs_lex = lex_env;\
-	frs_top->frs_bds_top = bds_top;  \
-	frs_top->frs_class = (class);  \
-	frs_top->frs_val = (val);  \
-	frs_top->frs_ihs = ihs_top;  \
-        setjmp(frs_top->frs_jmpbuf)
+	_frs_top->frs_lex = lex_env;\
+	_frs_top->frs_bds_top = bds_top;  \
+	_frs_top->frs_class = (class);  \
+	_frs_top->frs_in_signal_handler = in_signal_handler;  \
+	_frs_top->frs_val = (val);  \
+	_frs_top->frs_ihs = ihs_top;  \
+         frs_top=_frs_top; \
+        setjmp(_frs_top->frs_jmpbuf); \
+	} while (0)
 
 #define frs_pop()	frs_top--
 
 
 /*  global variables used during non-local jump  */
 
-bool nlj_active;		/* true during non-local jump */
-frame_ptr nlj_fr;		/* frame to return  */
-object nlj_tag;			/* throw-tag, block-id, or */
+EXTER bool nlj_active;		/* true during non-local jump */
+EXTER frame_ptr nlj_fr;		/* frame to return  */
+EXTER object nlj_tag; 			/* throw-tag, block-id, or */
 				/* (tagbody-id . label).   */
 
 
