@@ -345,7 +345,7 @@ struct bitvector {		/*  bitvector header  */
 				/*  st_fillp is equal to st_dim.  */
 	char	*bv_self;	/*  pointer to the bitvector  */
 	object	bv_displaced;	/*  displaced  */
-	short	bv_elttype;	/*  not used  */
+	short	bv_elttype;	/*  aet_bit  */
 	short	bv_offset;	/*  bitvector offset  */
 				/*  the position of the first bit  */
 				/*  in the first byte  */
@@ -835,7 +835,7 @@ EXTER struct call_data fcall;
 
 #define RETURN(n,typ,val1,listvals) \
    do{typ _val1 = val1; object *_p=&fcall.values[1]; listvals; fcall.nvalues= n; return _val1;}while(0)
-#define CALL(n,form) (VFUN_NARGS=n,form)
+#define FUNCALL(n,form) (VFUN_NARGS=n,form)
 	
 
 /* we sometimes have to touch the header of arrays or structures
