@@ -30,7 +30,7 @@ T7:;
 	base[0]= (V2);
 	base[1]= VV[1];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T10;}
@@ -47,7 +47,7 @@ T18:;
 	base[1]= (V2);
 	base[2]= (V7);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T22;}
@@ -76,7 +76,7 @@ T41:;
 	base[1]= (V2);
 	base[2]= (V13);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk16)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T45;}
@@ -138,7 +138,7 @@ static object LI2(V16,va_alist)
 	goto T57;}
 	V17= make_cons((V17),Cnil);
 T57:;
-	V18= (*(LnkLI22))((V18));
+	V18= (*(LnkLI21))((V18));
 	if(!((length((V17)))==(1))){
 	goto T64;}
 	{register object V27;
@@ -176,7 +176,7 @@ T64:;
 	{register object V32;
 	base[1]= (V18);
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk23)();
+	(void) (*Lnk22)();
 	vs_top=sup;
 	base[0]= vs_base[0];
 	base[1]= (V26);
@@ -185,7 +185,7 @@ T64:;
 	base[4]= (V25);
 	base[5]= (V17);
 	vs_top=(vs_base=base+0)+6;
-	(void) (*Lnk24)();
+	(void) (*Lnk23)();
 	vs_top=sup;
 	V32= vs_base[0];
 	if(((V23))==Cnil){
@@ -212,12 +212,12 @@ T98:;
 	V34= vs_base[0];
 T112:;
 	base[0]= (V32);
-	base[1]= (*(LnkLI25))((V20),(V34));
+	base[1]= (*(LnkLI24))((V20),(V34));
 	base[2]= (V34);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk26)();
+	(void) (*Lnk25)();
 	vs_top=sup;
-	if(((*(LnkLI27))((V34),(V17)))==Cnil){
+	if(((*(LnkLI26))((V34),(V17)))==Cnil){
 	goto T119;}
 	goto T102;
 T119:;
@@ -239,7 +239,7 @@ TTL:;
 	VMR3(V40)}
 T125:;
 	{object V41;
-	V41= (*(LnkLI27))(cdr((V38)),cdr((V39)));
+	V41= (*(LnkLI26))(cdr((V38)),cdr((V39)));
 	if(((V41))==Cnil){
 	goto T129;}
 	if(!(((fix(car((V38))))+1)>=(fix(car((V39)))))){
@@ -289,7 +289,7 @@ static object LI5(va_alist)
 	{object V53;
 	V54 = make_fixnum(length((V51)));
 	V53= make_cons(V54,Cnil);
-	{object V55 = (VFUN_NARGS=5,(*(LnkLI28))((V53),VV[8],Ct,VV[9],(V51)));
+	{object V55 = (VFUN_NARGS=5,(*(LnkLI27))((V53),VV[8],Ct,VV[9],(V51)));
 	VMR5(V55)}}}
 	}
 /*	local entry for function ARRAY-DIMENSIONS	*/
@@ -957,7 +957,7 @@ T312:;
 	vs_top=sup;
 	V182= vs_base[0];
 	V183 = make_fixnum(V174);
-	(void)((VFUN_NARGS=6,(*(LnkLI29))((V172),/* INLINE-ARGS */V181,VV[8],V182,VV[11],V183)));
+	(void)((VFUN_NARGS=6,(*(LnkLI28))((V172),/* INLINE-ARGS */V181,VV[8],V182,VV[11],V183)));
 	(void)(aset1((V172),V174,(V171)));
 	base[0]= (V172);
 	base[1]= make_fixnum((V174)+1);
@@ -1043,7 +1043,7 @@ T337:;
 T344:;
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk30)();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
 	goto T341;}
@@ -1055,7 +1055,7 @@ T344:;
 T343:;
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk30)();
+	(void) (*Lnk29)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T341;}
@@ -1087,30 +1087,25 @@ T360:;
 	 while(!endp(V205))
 	 {vs_push(car(V205));V205=cdr(V205);}
 	vs_base=base+0;}
-	(void) (*Lnk28)();
+	(void) (*Lnk27)();
 	vs_top=sup;
 	V204= vs_base[0];
 	if((cdr((V192)))==Cnil){
 	goto T372;}
 	V206= cdr((V192));
-	V207= (*(LnkLI31))((V191));
+	V207= (*(LnkLI30))((V191));
 	if(!(equal(/* INLINE-ARGS */V206,cdr(/* INLINE-ARGS */V207)))){
 	goto T373;}
 	if(!(((V194))==(VV[15]))){
 	goto T372;}
-	base[1]= (V192);
-	vs_top=(vs_base=base+1)+1;
+	base[0]= (V192);
+	vs_top=(vs_base=base+0)+1;
 	Llast();
 	vs_top=sup;
-	V209= vs_base[0];
-	base[0]= car(V209);
-	base[1]= symbol_value(VV[16]);
-	vs_top=(vs_base=base+0)+2;
-	Lmod();
-	vs_top=sup;
 	V208= vs_base[0];
-	if(!((0)==(fix(V208)))){
-	goto T373;}
+	{int V209= fix(car(V208));
+	if(!((0)==((V209>=0&&(8)>0?(V209)%(8):imod(V209,8))))){
+	goto T373;}}
 T372:;
 	base[0]= (V191);
 	base[1]= (V204);
@@ -1118,17 +1113,17 @@ T372:;
 	base[3]= small_fixnum(0);
 	base[5]= (V204);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk32)();
+	(void) (*Lnk31)();
 	vs_top=sup;
 	V210= vs_base[0];
 	base[5]= (V191);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk32)();
+	(void) (*Lnk31)();
 	vs_top=sup;
 	V211= vs_base[0];
 	base[4]= (number_compare(V210,V211)<=0?(V210):V211);
 	vs_top=(vs_base=base+0)+5;
-	(void) (*Lnk33)();
+	(void) (*Lnk32)();
 	vs_top=sup;
 	goto T371;
 T373:;
@@ -1140,7 +1135,7 @@ T373:;
 	Lmake_list();
 	vs_top=sup;
 	V212= vs_base[0];
-T400:;
+T397:;
 	base[0]= (V191);
 	{object V213;
 	V213= (V212);
@@ -1148,10 +1143,10 @@ T400:;
 	 while(!endp(V213))
 	 {vs_push(car(V213));V213=cdr(V213);}
 	vs_base=base+0;}
-	(void) (*Lnk34)();
+	(void) (*Lnk33)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T403;}
+	goto T400;}
 	base[0]= (V204);
 	base[2]= (V191);
 	{object V214;
@@ -1165,14 +1160,14 @@ T400:;
 	base[1]= vs_base[0];
 	base[2]= (V212);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk26)();
+	(void) (*Lnk25)();
 	vs_top=sup;
-T403:;
-	if(((*(LnkLI27))((V212),(V192)))==Cnil){
-	goto T413;}
+T400:;
+	if(((*(LnkLI26))((V212),(V192)))==Cnil){
+	goto T410;}
 	goto T371;
-T413:;
-	goto T400;}
+T410:;
+	goto T397;}
 T371:;
 	base[0]= (V191);
 	base[1]= (V204);
@@ -1182,18 +1177,18 @@ T371:;
 	{object V215 = vs_base[0];
 	VMR25(V215)}}}
 	}}
-static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* ARRAY-IN-BOUNDS-P */
-static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* COPY-ARRAY-PORTION */
-static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* ARRAY-TOTAL-SIZE */
-static object  LnkTLI31(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[31],&LnkLI31,1,ap);} /* ARRAY-DIMENSIONS */
-static LnkT28(){ call_or_link(VV[28],&Lnk28);} /* MAKE-ARRAY */
-static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* ARRAY-HAS-FILL-POINTER-P */
-static object  LnkTLI29(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[29],&LnkLI29,ap);} /* ADJUST-ARRAY */
-static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* MAKE-ARRAY */
-static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[27],&LnkLI27,2,ap);} /* INCREMENT-CURSOR */
-static LnkT26(){ call_or_link(VV[26],&Lnk26);} /* ASET-BY-CURSOR */
-static object  LnkTLI25(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[25],&LnkLI25,2,ap);} /* SEQUENCE-CURSOR */
-static LnkT24(){ call_or_link(VV[24],&Lnk24);} /* MAKE-ARRAY1 */
-static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* GET-AELTTYPE */
-static object  LnkTLI22(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[22],&LnkLI22,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
-static LnkT17(){ call_or_link(VV[17],&Lnk17);} /* SUBTYPEP */
+static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* ARRAY-IN-BOUNDS-P */
+static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* COPY-ARRAY-PORTION */
+static LnkT31(){ call_or_link(VV[31],&Lnk31);} /* ARRAY-TOTAL-SIZE */
+static object  LnkTLI30(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[30],&LnkLI30,1,ap);} /* ARRAY-DIMENSIONS */
+static LnkT27(){ call_or_link(VV[27],&Lnk27);} /* MAKE-ARRAY */
+static LnkT29(){ call_or_link(VV[29],&Lnk29);} /* ARRAY-HAS-FILL-POINTER-P */
+static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* ADJUST-ARRAY */
+static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[27],&LnkLI27,ap);} /* MAKE-ARRAY */
+static object  LnkTLI26(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[26],&LnkLI26,2,ap);} /* INCREMENT-CURSOR */
+static LnkT25(){ call_or_link(VV[25],&Lnk25);} /* ASET-BY-CURSOR */
+static object  LnkTLI24(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[24],&LnkLI24,2,ap);} /* SEQUENCE-CURSOR */
+static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* MAKE-ARRAY1 */
+static LnkT22(){ call_or_link(VV[22],&Lnk22);} /* GET-AELTTYPE */
+static object  LnkTLI21(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[21],&LnkLI21,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
+static LnkT16(){ call_or_link(VV[16],&Lnk16);} /* SUBTYPEP */
