@@ -24,9 +24,9 @@ static object LI1();
 #define VMV1 vs_reserve(3);
 #define VMR1(VMT1) vs_top=base ; return(VMT1);
 static object LI2();
-static int VK2defaults[8]={-1,-2,-1,-2,-2,-2,18,-2};
-static struct { short n,allow_other_keys;int *defaults;
-	 int keys[8];} LI2key={8,0,VK2defaults,{19,20,21,11,14,9,7,8}};
+static object VK2defaults[8]={(void *)-1,(void *)-2,(void *)-1,(void *)-2,(void *)-2,(void *)-2,(void *)17,(void *)-2};
+static struct { short n,allow_other_keys;object *defaults;
+	 KEYTYPE keys[8];} LI2key={8,0,VK2defaults,{(void *)18,(void *)19,(void *)20,(void *)11,(void *)14,(void *)9,(void *)7,(void *)8}};
 #define VMB2 register object *base=vs_top; object  V30; object Vcs[17];
 #define VMS2  register object *sup=vs_top+8;vs_top=sup;
 #define VMV2 vs_reserve(8);
@@ -142,9 +142,9 @@ static object LI24();
 #define VMV24 vs_reserve(2);
 #define VMR24(VMT24) vs_top=base ; return(VMT24);
 static object LI25();
-static struct { short n,allow_other_keys;int *defaults;
-	 int keys[7];} LI25key={7,0,(int *)Cstd_key_defaults,{19,20,21,11,9,7,8}};
-#define VMB25 register object *base=vs_top; object  V211 ,V210 ,V209 ,V208 ,V207 ,V206 ,V203 ,V201; object Vcs[17];
+static struct { short n,allow_other_keys;object *defaults;
+	 KEYTYPE keys[7];} LI25key={7,0,Cstd_key_defaults,{(void *)18,(void *)19,(void *)20,(void *)11,(void *)9,(void *)7,(void *)8}};
+#define VMB25 register object *base=vs_top; object  V211 ,V210 ,V208 ,V207 ,V206 ,V203 ,V201; object Vcs[17];
 #define VMS25  register object *sup=vs_top+6;vs_top=sup;
 #define VMV25 vs_reserve(6);
 #define VMR25(VMT25) vs_top=base ; return(VMT25);
@@ -173,8 +173,8 @@ static struct { short n,allow_other_keys;int *defaults;
 #define VM3 0
 #define VM2 8
 #define VM1 3
-static char * VVi[36]={
-#define Cdata VV[35]
+static char * VVi[35]={
+#define Cdata VV[34]
 (char *)(LI1),
 (char *)(LI2),
 (char *)(&LI2key),
@@ -204,33 +204,33 @@ static char * VVi[36]={
 (char *)(&LI25key)
 };
 #define VV ((object *)VVi)
-static  LnkT34() ;
-static  (*Lnk34)() = LnkT34;
 static  LnkT33() ;
 static  (*Lnk33)() = LnkT33;
 static  LnkT32() ;
 static  (*Lnk32)() = LnkT32;
-static object  LnkTLI31() ;
-static object  (*LnkLI31)() = LnkTLI31;
-static  LnkT28() ;
-static  (*Lnk28)() = LnkT28;
-static  LnkT30() ;
-static  (*Lnk30)() = LnkT30;
-static object  LnkTLI29() ;
-static object  (*LnkLI29)() = LnkTLI29;
+static  LnkT31() ;
+static  (*Lnk31)() = LnkT31;
+static object  LnkTLI30() ;
+static object  (*LnkLI30)() = LnkTLI30;
+static  LnkT27() ;
+static  (*Lnk27)() = LnkT27;
+static  LnkT29() ;
+static  (*Lnk29)() = LnkT29;
 static object  LnkTLI28() ;
 static object  (*LnkLI28)() = LnkTLI28;
 static object  LnkTLI27() ;
 static object  (*LnkLI27)() = LnkTLI27;
-static  LnkT26() ;
-static  (*Lnk26)() = LnkT26;
-static object  LnkTLI25() ;
-static object  (*LnkLI25)() = LnkTLI25;
-static  LnkT24() ;
-static  (*Lnk24)() = LnkT24;
+static object  LnkTLI26() ;
+static object  (*LnkLI26)() = LnkTLI26;
+static  LnkT25() ;
+static  (*Lnk25)() = LnkT25;
+static object  LnkTLI24() ;
+static object  (*LnkLI24)() = LnkTLI24;
 static  LnkT23() ;
 static  (*Lnk23)() = LnkT23;
-static object  LnkTLI22() ;
-static object  (*LnkLI22)() = LnkTLI22;
-static  LnkT17() ;
-static  (*Lnk17)() = LnkT17;
+static  LnkT22() ;
+static  (*Lnk22)() = LnkT22;
+static object  LnkTLI21() ;
+static object  (*LnkLI21)() = LnkTLI21;
+static  LnkT16() ;
+static  (*Lnk16)() = LnkT16;
