@@ -18,7 +18,7 @@ license along with GCL; see the file COPYING.  If not, write to the
 Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include "include.h"
+#include "config.h"
 #include "genpari.h"
 #include "arith.h"
 
