@@ -750,11 +750,11 @@ va_dcl
 
 ALLOCATE:
 	if (t == t_contiguous) 
-	  CALL(2,fSallocate_contiguous_pages(npages,really_do));
+	  FUNCALL(2,fSallocate_contiguous_pages(npages,really_do));
 	  
         else
   	  if (t==t_relocatable) 
-	    CALL(2,fSallocate_relocatable_pages(npages,really_do));
+	    FUNCALL(2,fSallocate_relocatable_pages(npages,really_do));
         else{
 	  
 	if (available_pages < tm->tm_maxpage - tm->tm_npage ||
