@@ -54,12 +54,12 @@ extern short aet_sizes[];
 
 #define N_FIXNUM_ARGS 6
 
-DEFUNO("AREF", object, fLaref, LISP, 2, ARRAY_RANK_LIMIT,
+DEFUNO("AREF", object, fLaref, LISP, 1, ARRAY_RANK_LIMIT,
        NONE, OO, II, II, II,Laref,"")
 (x, i, va_alist)
   object x;
   int i;
-
+  va_dcl
 { int n = VFUN_NARGS;
   int i1;
   va_list ap;
@@ -69,6 +69,7 @@ DEFUNO("AREF", object, fLaref, LISP, 2, ARRAY_RANK_LIMIT,
      if (x->a.a_rank != rank)
        FEerror(" ~a has wrong rank",x);
      if (rank == 1) return fSaref1(x,i);
+     if (rank == 0) return fSaref1(x,0);
      va_start(ap);
      m = 0;
      k = i;
@@ -77,20 +78,22 @@ DEFUNO("AREF", object, fLaref, LISP, 2, ARRAY_RANK_LIMIT,
      rank-- ;
      while(1) 
        {
-	 if (k > x->a.a_dims[m])
+	 if (k >= x->a.a_dims[m])
 	   FEerror("Index ~a to array is too large",1,make_fixnum (m));
 	 i1 += k;
-	 if (m < rank)
+	 m ++;
+	 if (m <= rank)
 	   { i1 = i1 * x->a.a_dims[m];
 	     if (m < N_FIXNUM_ARGS)
 	       { k = va_arg(ap,int);}
 	     else {object x = va_arg(ap,object);
 		   check_type(x,t_fixnum);
 		   k = Mfix(x);}
-	     m++;}
+	  
+	   }
 	 else break;}
      va_end(ap);
-     return fSaref1(x,i);
+     return fSaref1(x,i1);
    }
   if (n > 2)
     { FEerror("Too many args (~a) to aref",1,make_fixnum(n));}
@@ -130,7 +133,7 @@ DEFUN("SVREF", object, fLsvref, LISP, 2, 2,
 }
     
 DEFUN("AREF1", object, fSaref1, SI, 2, 2,
-      ONE_VAL, OO, IO, OO,OO,
+      NONE, OO, IO, OO,OO,
       "For array X and index I it returns (aref x i) as if x were \
 1 dimensional, even though its rank may be bigger than 1")
 (x, i)
@@ -140,6 +143,7 @@ DEFUN("AREF1", object, fSaref1, SI, 2, 2,
   switch (type_of(x)) {
   case t_array:
   case t_vector:
+  case t_bitvector:
     if (x->v.v_dim <= i)
       i = fScheck_bounds_bounds(x, i);
     switch (x->v.v_elttype) {
@@ -188,6 +192,7 @@ DEFUN("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,"")
   switch (type_of(x)) {
   case t_array:
   case t_vector:
+  case t_bitvector:
     if (x->v.v_dim <= i)
       i = fScheck_bounds_bounds(x, i);
     switch (x->v.v_elttype) {
@@ -252,21 +257,26 @@ DEFUN("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,"")
   return val;
 }
 
-DEFUNO("ASET", object, fSaset, SI, 3, ARG_LIMIT, NONE, OO,
-       IO, OO, OO,siLaset,"")
- (x,i,y, va_alist)
+DEFUNO("ASET", object, fSaset, SI, 1, ARG_LIMIT, NONE, OO,
+       OO, OO, OO,siLaset,"")
+ (x,ii,y, va_alist)
   object x,y;
-  int i;
+  object ii;
   va_dcl
 { int i1;
   int n = VFUN_NARGS;
+  int i;
   va_list ap;
   if (type_of(x) == t_array)
     {int m,k ;
      int rank = n - 2; 
      if (x->a.a_rank != rank)
        FEerror(" ~a has wrong rank",x);
-     if (rank == 1) return fSaset1(x,i,y);
+     if (rank == 0) return fSaset1(x,0,ii);
+     ASSURE_TYPE(ii,t_fixnum);
+     i = fix(ii);
+     if (rank == 1)
+       return fSaset1(x,i,y);
      va_start(ap);
      m = 0;
      k = i;
@@ -297,7 +307,9 @@ DEFUNO("ASET", object, fSaset, SI, 3, ARG_LIMIT, NONE, OO,
      va_end(ap);
    }
   else 
-    { i1 = i ;}
+    { ASSURE_TYPE(ii,t_fixnum);
+     i1 = fix(ii);
+      }
   return fSaset1(x,i1,y);
    
 }
@@ -358,14 +370,21 @@ int n;int elt_type;object staticp;va_dcl
 	fillp=va_arg(Iap,object);
 	if (fillp == Cnil)
 	  {x->v.v_hasfillp = 0;
-	   x->v.v_fillp = n;  }
-	else {
-	  ASSURE_TYPE(fillp,t_fixnum);
-	  x->v.v_fillp = Mfix(fillp);
-	  x->v.v_hasfillp = 1;
-	  if (x->v.v_fillp > n) FEerror("bad fillp",0);
-	}
-	va_end(Iap);
+	   x->v.v_fillp = n;
+	 }
+	else 
+	  if(type_of(fillp) == t_fixnum)
+	  {	
+	    x->v.v_fillp = Mfix(fillp);
+	    if (x->v.v_fillp > n) FEerror("bad fillp",0);
+	    x->v.v_hasfillp = 1;
+	  }
+	else
+	  {
+	    x->v.v_fillp = n;
+	    x->v.v_hasfillp = 1;
+	  }
+
       }
 
       if( --Inargs < 0)goto LA2;
@@ -396,11 +415,12 @@ int n;int elt_type;object staticp;va_dcl
       displaced_index_offset= 0;
     LA6:
       x->v.v_adjustable = 1;
-
+      va_end(Iap);
       { if (displaced_to == Cnil)
 	  array_allocself(x,staticp!=Cnil,initial_element);
 	else { displace(x,displaced_to,displaced_index_offset);}
 	END_NO_INTERRUPT;
+
 	return x;
       }
     }
@@ -1047,7 +1067,8 @@ object array,val,cursor;
 	object ind[ARRAY_RANK_LIMIT];
 	/* 3 args */
 	ind[0]=array;
-	ind[1]=(object) Mfix(MMcar(cursor));
+	if (cursor==sLnil) {fSaset1(array,0,val); RETURN1(array);}
+	ind[1]=MMcar(cursor);
 	i = 2;
 	for (x = MMcdr(cursor);  !endp(x);  x = MMcdr(x))
 	  { ind[i++] = MMcar(x);}
