@@ -854,7 +854,7 @@ va_dcl
 
 
 struct key {short n,allow_other_keys;
-	    iobject *defaults;
+	    object *defaults;
 	    iobject keys[1];
 	   };
 
@@ -873,7 +873,7 @@ parse_key_new(n,base,keys,ap)
  /* from here down identical to parse_key_rest */
  new = new + n ;
   {int j=keys->n;
-   object *p= (object *)(keys->defaults);
+   object *p= (keys->defaults);
    while (--j >=0) base[j]=p[j];
  }
  {if (n==0){ return;}
@@ -930,7 +930,7 @@ parse_key_rest(rest,n,base,keys,ap)
     
  new = new + n ;
   {int j=keys->n;
-   object *p= (object *)(keys->defaults);
+   object *p= (keys->defaults);
    while (--j >=0) base[j]=p[j];
  }
  {if (n==0){ return;}
@@ -977,9 +977,10 @@ set_key_struct(ks,data)
 {int i=ks->n;
  while (--i >=0)
    {ks->keys[i].o =   data->cfd.cfd_self[ ks->keys[i].i ];
-    if (ks->defaults != (iobject *)Cstd_key_defaults)
-     {int m=ks->defaults[i].i;
-        ks->defaults[i].o=
+    if (ks->defaults != Cstd_key_defaults)
+     { iobject *def = (iobject *) (ks->defaults);
+       int m=def[i].i;
+        def[i].o=
 	  (m==-2 ? Cnil :
 	   m==-1 ? (object)0 :
 	   data->cfd.cfd_self[m]);}
