@@ -417,7 +417,7 @@ struct bitvector {		/*  bitvector header  */
 				/*  st_fillp is equal to st_dim.  */
 	char	*bv_self;	/*  pointer to the bitvector  */
 	object	bv_displaced;	/*  displaced  */
-	short	bv_elttype;	/*  not used  */
+	short	bv_elttype;	/*  aet_bit  */
 	short	bv_offset;	/*  bitvector offset  */
 				/*  the position of the first bit  */
 				/*  in the first byte  */
@@ -907,7 +907,7 @@ EXTER struct call_data fcall;
 
 #define RETURN(n,typ,val1,listvals) \
    do{typ _val1 = val1; object *_p=&fcall.values[1]; listvals; fcall.nvalues= n; return _val1;}while(0)
-#define CALL(n,form) (VFUN_NARGS=n,form)
+#define FUNCALL(n,form) (VFUN_NARGS=n,form)
 	
 
 /* we sometimes have to touch the header of arrays or structures
@@ -1531,10 +1531,8 @@ object fSallocate_contiguous_pages();
 object fSallocate_relocatable_pages();
 /*  array.c  */
 enum aelttype Iarray_element_type();
-object aref();
-object aset();
-object aref1();
-object aset1();
+object fSaref1();
+object fSaset1();
 EXTER object sLarray_dimension_limit;
 EXTER object sLarray_total_size_limit;
 object fSmake_array1();
@@ -1943,6 +1941,7 @@ EXTER object siSsharp_comma;
 EXTER bool escape_flag;
 EXTER object delimiting_char;
 EXTER bool detect_eos_flag;
+EXTER object read_byte1(); 
 /* bool in_list_flag; */
 EXTER bool dot_flag;
 EXTER bool preserving_whitespace_flag;
@@ -2206,7 +2205,8 @@ object make_integer();
 #define CMPcddadr(x)	(x)->c.c_cdr->c.c_car->c.c_cdr->c.c_cdr
 #define CMPcdddar(x)	(x)->c.c_car->c.c_cdr->c.c_cdr->c.c_cdr
 #define CMPcddddr(x)	(x)->c.c_cdr->c.c_cdr->c.c_cdr->c.c_cdr
-
+#define CMPfuncall	funcall
+#define Creturn(v) return((vs_top=vs,(v)))
 /* end for cmp*/
 
 /* 2^6 is the limit on the number of args */
@@ -2277,6 +2277,9 @@ object on_stack_make_list();
 #define ON_STACK_LIST_VECTOR list_vector
 #define ON_STACK_MAKE_LIST make_list
 #endif
+#ifndef KEYTYPE
+#define KEYTYPE void *
+#endif
 
 
 
@@ -2335,12 +2338,12 @@ void isetq_fix();
 #define SETQ_IO(var,alloc,val) {object _xx =(val) ; \
 			      int _n = obj_replace_copy1(_xx,var); \
 			    if(_n) var = obj_replace_copy2(_xx,alloca(_n));}
-#define IDECL(a,b,c) ulong b[4];a =(b[0]=0x1010000 +4,b) ; object c
+#define IDECL(a,b,c) our_ulong b[4];a =(b[0]=0x1010000 +4,b) ; object c
 #else
 GEN setq_io(),setq_ii();
 #define SETQ_IO(x,alloc,val)   (x)=setq_io(x,&alloc,val)
 #define SETQ_II(x,alloc,val)   (x)=setq_ii(x,&alloc,val)
-#define IDECL(a,b,c) ulong b[4];a =(b[0]=0x1010000 +4,b);object c
+#define IDECL(a,b,c) our_ulong b[4];a =(b[0]=0x1010000 +4,b);object c
 #endif
 
 #define	cclosure_call	funcall
