@@ -932,14 +932,8 @@ LAMBDA:
 object
 Ieval(form)
      object form;
-{ object *base=vs_base;
-  object *top = vs_top;
-  object ans;
-  eval(form);
-  ans = Ivs_values();
-  vs_top = top;
-  vs_base = base;
-  return ans;
+{ eval(form);
+  return Ivs_values();
 }
 #endif
   
