@@ -441,6 +441,7 @@ DIRECTIVE:
 
 
 fmt_max_param(n)
+int n;
 {
 	if (fmt_nparam > n)
 		fmt_error("too many parameters");
@@ -480,6 +481,7 @@ int i, *p, t, v;
 
 
 fmt_ascii(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, colinc, minpad, padchar;
 	object x;
@@ -517,6 +519,7 @@ fmt_ascii(colon, atsign)
 }
 
 fmt_S_expression(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, colinc, minpad, padchar;
 	object x;
@@ -554,6 +557,7 @@ fmt_S_expression(colon, atsign)
 }
 
 fmt_decimal(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, padchar, commachar;
 
@@ -566,6 +570,7 @@ fmt_decimal(colon, atsign)
 }
 
 fmt_binary(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, padchar, commachar;
 
@@ -578,6 +583,7 @@ fmt_binary(colon, atsign)
 }
 
 fmt_octal(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, padchar, commachar;
 
@@ -590,6 +596,7 @@ fmt_octal(colon, atsign)
 }
 
 fmt_hexadecimal(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, padchar, commachar;
 
@@ -602,6 +609,7 @@ fmt_hexadecimal(colon, atsign)
 }
 
 fmt_radix(colon, atsign)
+     bool colon,atsign;
 {
 	int radix, mincol, padchar, commachar;
 	object x;
@@ -682,7 +690,9 @@ fmt_radix(colon, atsign)
 }	
 
 fmt_integer(x, colon, atsign, radix, mincol, padchar, commachar)
-object x;
+     bool colon,atsign;
+     int radix, mincol, padchar, commachar;
+     object x;
 {
 	int l, l1;
 	int s;
@@ -833,6 +843,7 @@ int s, i;
 }
 
 fmt_roman(i, one, five, ten, colon)
+     int i, one, five, ten, colon;
 {
 	int j;
 
@@ -855,6 +866,7 @@ fmt_roman(i, one, five, ten, colon)
 }
 
 fmt_plural(colon, atsign)
+     bool colon,atsign;
 {
 	fmt_max_param(0);
 	if (colon) {
@@ -875,6 +887,7 @@ fmt_plural(colon, atsign)
 }
 
 fmt_character(colon, atsign)
+     bool colon,atsign;
 {
 	object x;
 	int i;
@@ -895,6 +908,7 @@ fmt_character(colon, atsign)
 }
 
 fmt_fix_float(colon, atsign)
+     bool colon,atsign;
 {
 	int w, d, k, overflowchar, padchar;
 	double f;
@@ -1050,6 +1064,7 @@ OVER:
 
 int
 fmt_exponent_length(e)
+ int e;
 {
 	int i;
 
@@ -1063,6 +1078,7 @@ fmt_exponent_length(e)
 }
 
 fmt_exponent(e)
+ int e;
 {
 	if (e == 0) {
 		writec_stream('0', fmt_stream);
@@ -1074,6 +1090,7 @@ fmt_exponent(e)
 }
 	
 fmt_exponent1(e)
+ int e;
 {
 	if (e == 0)
 		return;
@@ -1082,6 +1099,7 @@ fmt_exponent1(e)
 }
 
 fmt_exponential_float(colon, atsign)
+     bool colon,atsign;
 {
 	int w, d, e, k, overflowchar, padchar, exponentchar;
 	double f;
@@ -1248,7 +1266,10 @@ fmt_exponential_float(colon, atsign)
 	writestr_stream(b, fmt_stream);
 	y = symbol_value(sLAread_default_float_formatA);
 	if (exponentchar < 0) {
-		if (y == sLlong_float || y == sLdouble_float)
+		if (y == sLlong_float || y == sLdouble_float
+		    || y == sLsingle_float 
+
+		    )
 			t = t_longfloat;
 		else
 			t = t_shortfloat;
@@ -1280,6 +1301,7 @@ OVER:
 }
 
 fmt_general_float(colon, atsign)
+     bool colon,atsign;
 {
 	int w, d, e, k, overflowchar, padchar, exponentchar;
 	int sign, exp;
@@ -1341,13 +1363,18 @@ fmt_general_float(colon, atsign)
 	}
 	dd = d - n;
 	if (0 <= dd && dd <= d) {
-		fmt_nparam = 5;
 		FMT_PARAM[0].fmt_param_value = ww;
+		if (w < 0) FMT_PARAM[0].fmt_param_type = fmt_null;
 		FMT_PARAM[1].fmt_param_value = dd;
 		FMT_PARAM[1].fmt_param_type = fmt_int;
 		FMT_PARAM[2].fmt_param_type = fmt_null;
-		FMT_PARAM[3] = FMT_PARAM[4];
-		FMT_PARAM[4] = FMT_PARAM[5];
+		if (fmt_nparam > 4)
+		  {FMT_PARAM[3] =    FMT_PARAM[4]; }
+		else FMT_PARAM[3].fmt_param_type = fmt_null;
+		if (fmt_nparam > 5)
+		  {FMT_PARAM[4] = FMT_PARAM[5];}
+		else FMT_PARAM[4].fmt_param_type = fmt_null;
+		fmt_nparam = 5;
 		--fmt_index;
 		fmt_fix_float(colon, atsign);
 		if (w >= 0)
@@ -1364,6 +1391,7 @@ fmt_general_float(colon, atsign)
 }
 
 fmt_dollars_float(colon, atsign)
+     bool colon,atsign;
 {
 	int d, n, w, padchar;
 	double f;
@@ -1448,6 +1476,7 @@ fmt_dollars_float(colon, atsign)
 }
 
 fmt_percent(colon, atsign)
+     bool colon,atsign;
 {
 	int n, i;
 
@@ -1464,6 +1493,7 @@ fmt_percent(colon, atsign)
 }
 
 fmt_ampersand(colon, atsign)
+     bool colon,atsign;
 {
 	int n;
 
@@ -1481,6 +1511,7 @@ fmt_ampersand(colon, atsign)
 }
 
 fmt_bar(colon, atsign)
+     bool colon,atsign;
 {
 	int n;
 
@@ -1493,6 +1524,7 @@ fmt_bar(colon, atsign)
 }
 
 fmt_tilde(colon, atsign)
+     bool colon,atsign;
 {
 	int n;
 
@@ -1505,6 +1537,7 @@ fmt_tilde(colon, atsign)
 }
 
 fmt_newline(colon, atsign)
+     bool colon,atsign;
 {
 	int c;
 
@@ -1520,6 +1553,7 @@ fmt_newline(colon, atsign)
 }
 
 fmt_tabulate(colon, atsign)
+     bool colon,atsign;
 {
 	int colnum, colinc;
 	int c, i;
@@ -1555,6 +1589,7 @@ fmt_tabulate(colon, atsign)
 }
 
 fmt_asterisk(colon, atsign)
+     bool colon,atsign;
 {
 	int n;
 
@@ -1578,6 +1613,7 @@ fmt_asterisk(colon, atsign)
 }	
 
 fmt_indirection(colon, atsign)
+     bool colon,atsign;
 { 	object endp_temp;
 	object s, l;
 	fmt_old;
@@ -1619,6 +1655,7 @@ fmt_indirection(colon, atsign)
 }
 
 fmt_case(colon, atsign)
+     bool colon,atsign;
 {
 	VOL object x;
 	VOL int i, j;
@@ -1686,6 +1723,7 @@ fmt_case(colon, atsign)
 }
 
 fmt_conditional(colon, atsign)
+     bool colon,atsign;
 {
 	int i, j, k;
 	object x;
@@ -1774,6 +1812,7 @@ fmt_conditional(colon, atsign)
 }	
 
 fmt_iteration(colon, atsign)
+     bool colon,atsign;
 { 	object endp_temp;
 	int i,n;
 	VOL int j;
@@ -1897,6 +1936,7 @@ fmt_iteration(colon, atsign)
 #define FORMAT_DIRECTIVE_LIMIT 100
 
 fmt_justification(colon, atsign)
+     bool colon,atsign;
 {
 	int mincol, colinc, minpad, padchar;
 	object fields[FORMAT_DIRECTIVE_LIMIT];
@@ -1994,6 +2034,7 @@ fmt_justification(colon, atsign)
 
 
 fmt_up_and_out(colon, atsign)
+     bool colon,atsign;
 {
 	int i, j, k;
 
@@ -2022,6 +2063,7 @@ fmt_up_and_out(colon, atsign)
 
 
 fmt_semicolon(colon, atsign)
+     bool colon,atsign;
 {
 	fmt_not_atsign(atsign);
 	if (!colon)
@@ -2108,6 +2150,7 @@ object c_apply_n();
 
 
 fmt_error(s)
+     char *s;
 {
 	vs_push(make_simple_string(s));
 	vs_push(make_fixnum(&ctl_string[ctl_index] - fmt_string->st.st_self));
