@@ -1152,8 +1152,8 @@ enum type t;
 		if (sgc_enabled==0) holepage = new_holepage;
 
 		nrbpage -= j;
-		if (nrbpage < 0)
-			error("no relocatable pages left");
+		if (nrbpage < 20)
+		  nrbpage = 20;
 
 		rb_start = heap_end + PAGESIZE*holepage;
 		rb_end = rb_start + PAGESIZE*nrbpage;
