@@ -2,15 +2,16 @@
 NewInit(){
 
 DEFUNO("BYE",int,fLbye,LISP
-   ,0,1,0 ,II,OO,OO,OO,Lby,"")
+   ,0,1,0    ,II,OO,OO,OO,Lby,"")
 DEFUNO("IDENTITY",object,fLidentity,LISP
-   ,1,1,0 ,OO,OO,OO,OO,Lidentity,"")
+   ,1,1,0    ,OO,OO,OO,OO,Lidentity,"")
 DEFUNO("LISP-IMPLEMENTATION-VERSION",object,fLlisp_implementation_version,LISP
-   ,0,0,0 ,OO,OO,OO,OO,Llisp_implementation_version,"")
+   ,0,0,0    ,OO,OO,OO,OO,Llisp_implementation_version,"")
 DEFVAR("*LISP-MAXPAGES*",sSAlisp_maxpagesA,SI,make_fixnum(real_maxpage),"")
 DEFVAR("*SYSTEM-DIRECTORY*",sSAsystem_directoryA,SI,make_simple_string(system_directory),"")
-DEFVAR("*MULTIPLY-STACKS*",sSAmultiply_stacksA,SI,((object)&Cnil_body) ,"")
+DEFVAR("*MULTIPLY-STACKS*",sSAmultiply_stacksA,SI,		((object)&Cnil_body) ,"")
 DEF_ORDINARY("TOP-LEVEL",sStop_level,SI,"")
+DEFVAR("*COMMAND-ARGS*",sSAcommand_argsA,SI,		((object)&Cnil_body)  ,"")
 DEFVAR("*AFTER-GBC-HOOK*",sSAafter_gbc_hookA,SI,((object)&Cnil_body)  ,"")
 DEFVAR("*IGNORE-MAXIMUM-PAGES*",sSAignore_maximum_pagesA,SI,((object)&Ct_body)  ,"")
 DEFUN("ALLOCATED",object,fSallocated,SI
@@ -36,9 +37,9 @@ DEFUNO("GET-HOLE-SIZE",object,fSget_hole_size,SI
 DEFUNO("SET-HOLE-SIZE",object,fSset_hole_size,SI
    ,1,2,0 ,OI,IO,OO,OO,siLset_hole_size,"")
 DEFUNO("GBC",object,fLgbc,LISP
-   ,1,1,0    ,OO,OO,OO,OO,Lgbc,"")
-DEFVAR("*NOTIFY-GBC*",sSAnotify_gbcA,SI,		((object)&Cnil_body) ,"")
-DEFVAR("*GBC-MESSAGE*",sSAgbc_messageA,SI,		((object)&Cnil_body) ,"")
+   ,1,1,0 ,OO,OO,OO,OO,Lgbc,"")
+DEFVAR("*NOTIFY-GBC*",sSAnotify_gbcA,SI,((object)&Cnil_body) ,"")
+DEFVAR("*GBC-MESSAGE*",sSAgbc_messageA,SI,((object)&Cnil_body) ,"")
 DEF_ORDINARY("COMMON",sLcommon,LISP,"")
 DEF_ORDINARY("NULL",sLnull,LISP,"")
 DEF_ORDINARY("CONS",sLcons,LISP,"")
@@ -97,16 +98,16 @@ DEF_ORDINARY("PLUSP",sLplusp,LISP,"")
 DEFCONST("CHAR-SIZE",sSchar_size,SI,(object)(small_fixnum_table+1024 +( 8  )) ,"Size in bits of a character")
 DEFCONST("SHORT-SIZE",sSshort_size,SI,(object)(small_fixnum_table+1024 +( 8 *sizeof(short) )) ,"Size in bits of a short integer")
 DEFUNO("FUNCALL",object,fLfuncall,LISP
-   ,1,63 ,0 ,OO,OO,OO,OO,Lfuncall,"")
+   ,1,63 ,0    ,OO,OO,OO,OO,Lfuncall,"")
 DEFUNO("APPLY",object,fLapply,LISP
-   ,2,63 ,0 ,OO,OO,OO,OO,Lapply,"")
+   ,2,63 ,0    ,OO,OO,OO,OO,Lapply,"")
 DEFUNO("EVAL",object,fLeval,LISP
-   ,1,1,0 ,OO,OO,OO,OO,Leval,"")
+   ,1,1,0    ,OO,OO,OO,OO,Leval,"")
 DEFUNO("CONSTANTP",object,fLconstantp,LISP
-   ,1,1,0 ,OO,OO,OO,OO,Lconstantp,"")
+   ,1,1,0    ,OO,OO,OO,OO,Lconstantp,"")
 DEF_ORDINARY("LAMBDA-BLOCK-EXPANDED",sSlambda_block_expanded,SI,"")
-DEFVAR("*BREAK-POINTS*",sSAbreak_pointsA,SI,((object)&Cnil_body) ,"")
-DEFVAR("*BREAK-STEP*",sSAbreak_stepA,SI,((object)&Cnil_body) ,"")
+DEFVAR("*BREAK-POINTS*",sSAbreak_pointsA,SI,		((object)&Cnil_body) ,"")
+DEFVAR("*BREAK-STEP*",sSAbreak_stepA,SI,		((object)&Cnil_body) ,"")
 DEFUNO("MACROEXPAND",object,fLmacroexpand,LISP
    ,1,2,0    ,OO,OO,OO,OO,Lmacroexpand,"")
 DEF_ORDINARY("FUNCALL",sLfuncall,LISP,"")
@@ -260,59 +261,59 @@ DEFCONST("ARRAY-DIMENSION-LIMIT", sLarray_dimension_limit,
 DEFCONST("ARRAY-TOTAL-SIZE-LIMIT", sLarray_total_size_limit,
 	 LISP, sLarray_dimension_limit,"")
 DEF_ORDINARY("BIT",sLbit,LISP,"")
-DEFUNO("AREF", object, fLaref, LISP, 2, 63 ,
-       0    , OO, II, II, II,Laref,"")
+DEFUNO("AREF", object, fLaref, LISP, 1, 63 ,
+       0 , OO, II, II, II,Laref,"")
 DEFUN("SVREF", object, fLsvref, LISP, 2, 2,
-       (1 << F_caller_sets_one_val) , OO, IO, OO,OO,
+      (1 << F_caller_sets_one_val) , OO, IO, OO,OO,
       "For array X and index I it returns (aref x i) ")
 DEFUN("AREF1", object, fSaref1, SI, 2, 2,
-       (1 << F_caller_sets_one_val) , OO, IO, OO,OO,
+      0 , OO, IO, OO,OO,
       "For array X and index I it returns (aref x i) as if x were 1 dimensional, even though its rank may be bigger than 1")
-DEFUN("ASET1", object, fSaset1, SI, 3, 3, 0    , OO, IO, OO,OO,"")
-DEFUNO("ASET", object, fSaset, SI, 3, 63 , 0    , OO,
-       IO, OO, OO,siLaset,"")
-DEFUNO("SVSET", object, fSsvset, SI, 3, 3, 0    , OO, IO, OO,
+DEFUN("ASET1", object, fSaset1, SI, 3, 3, 0 , OO, IO, OO,OO,"")
+DEFUNO("ASET", object, fSaset, SI, 1, 63 , 0 , OO,
+       OO, OO, OO,siLaset,"")
+DEFUNO("SVSET", object, fSsvset, SI, 3, 3, 0 , OO, IO, OO,
        OO,siLsvset,"")
-DEFUN("MAKE-VECTOR1",object,fSmake_vector1,SI,3,8,0    ,OI,
+DEFUN("MAKE-VECTOR1",object,fSmake_vector1,SI,3,8,0 ,OI,
       IO,OO,OO,"")
-DEFUN("GET-AELTTYPE",enum aelttype,fSget_aelttype,SI,1,1,0    ,IO,OO,OO,OO,"")
-DEFUNO("MAKE-VECTOR",object,fSmake_vector,SI,7,8,0    ,
+DEFUN("GET-AELTTYPE",enum aelttype,fSget_aelttype,SI,1,1,0 ,IO,OO,OO,OO,"")
+DEFUNO("MAKE-VECTOR",object,fSmake_vector,SI,7,8,0 ,
        OO,OO,OO,OO,siLmake_vector,"")
 DEFUN("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
-      0    ,OI,OO,OI,OO,"")
+      0 ,OI,OO,OI,OO,"")
 DEFUN("COPY-ARRAY-PORTION",object,fScopy_array_portion,SI,4,
-      5,0    ,OO,OI,II,OO,
+      5,0 ,OO,OI,II,OO,
    "Copy elements from X to Y starting at x[i1] to x[i2] and doing N1 elements if N1 is supplied otherwise, doing the length of X - I1 elements.  If the types of the arrays are not the same, this has implementation dependent results.")
 DEFUNO("FILL-POINTER-SET",int,fSfill_pointer_set,SI,2,2,
-       0    ,IO,IO,OO,OO,siLfill_pointer_set,"")
-DEFUNO("FILL-POINTER",int,fLfill_pointer,LISP,1,1,0    ,IO,
+       0 ,IO,IO,OO,OO,siLfill_pointer_set,"")
+DEFUNO("FILL-POINTER",int,fLfill_pointer,LISP,1,1,0 ,IO,
        OO,OO,OO,Lfill_pointer,"")
 DEFUN("ARRAY-HAS-FILL-POINTER-P",object,
-      fLarray_has_fill_pointer_p,LISP,1,1,0    ,OO,OO,OO,OO,"")
+      fLarray_has_fill_pointer_p,LISP,1,1,0 ,OO,OO,OO,OO,"")
 DEFUNO("ARRAY-ELEMENT-TYPE",object,fLarray_element_type,
-       LISP,1,1,0    ,OO,OO,OO,OO,Larray_element_type,"")
+       LISP,1,1,0 ,OO,OO,OO,OO,Larray_element_type,"")
 DEFUNO("ADJUSTABLE-ARRAY-P",object,fLadjustable_array_p,
-       LISP,1,1,0    ,OO,OO,OO,OO,Ladjustable_array_p,"")
+       LISP,1,1,0 ,OO,OO,OO,OO,Ladjustable_array_p,"")
 DEFUNO("DISPLACED-ARRAY-P",object,fSdisplaced_array_p,SI,1,
-       1,0    ,OO,OO,OO,OO,siLdisplaced_array_p,"")
-DEFUNO("ARRAY-RANK",int,fLarray_rank,LISP,1,1,0    ,IO,OO,OO,
+       1,0 ,OO,OO,OO,OO,siLdisplaced_array_p,"")
+DEFUNO("ARRAY-RANK",int,fLarray_rank,LISP,1,1,0 ,IO,OO,OO,
        OO,Larray_rank,"")
 DEFUNO("ARRAY-DIMENSION",int,fLarray_dimension,LISP,2,2,
-       0    ,IO,IO,OO,OO,Larray_dimension,"")
-DEFUNO("REPLACE-ARRAY",object,fSreplace_array,SI,2,2,0    ,
+       0 ,IO,IO,OO,OO,Larray_dimension,"")
+DEFUNO("REPLACE-ARRAY",object,fSreplace_array,SI,2,2,0 ,
        OO,OO,OO,OO,siLreplace_array,"")
 DEFUNO("ARRAY-TOTAL-SIZE",int,fLarray_total_size,LISP,1,1,
-       0    ,IO,OO,OO,OO,Larray_total_size,"")
+       0 ,IO,OO,OO,OO,Larray_total_size,"")
 DEFUNO("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
-       0    ,OO,OO,OO,OO,siLaset_by_cursor,"")
-DEFVAR("*MATCH-DATA*",sSAmatch_dataA,SI,((object)&Cnil_body)  ,"")
-DEFVAR("*CASE-FOLD-SEARCH*",sSAcase_fold_searchA,SI,((object)&Cnil_body)  ,
+       0 ,OO,OO,OO,OO,siLaset_by_cursor,"")
+DEFVAR("*MATCH-DATA*",sSAmatch_dataA,SI,		((object)&Cnil_body)  ,"")
+DEFVAR("*CASE-FOLD-SEARCH*",sSAcase_fold_searchA,SI,		((object)&Cnil_body)  ,
        "Non nil means that a string-match should ignore case")
-DEFUN("MATCH-BEGINNING",int,fSmatch_beginning,SI,1,1,0 ,II,OO,OO,OO,
+DEFUN("MATCH-BEGINNING",int,fSmatch_beginning,SI,1,1,0    ,II,OO,OO,OO,
    "Returns the beginning of the I'th match from the previous STRING-MATCH, where the 0th is for the whole regexp and the subsequent ones match parenthetical expressions.  -1 is returned if there is no match, or if the *match-data* vector is not a fixnum array.")
-DEFUN("MATCH-END",int,fSmatch_end,SI,1,1,0 ,II,OO,OO,OO,
+DEFUN("MATCH-END",int,fSmatch_end,SI,1,1,0    ,II,OO,OO,OO,
    "Returns the end of the I'th match from the previous STRING-MATCH")
-DEFUN("STRING-MATCH",int,fSstring_match,SI,2,4,0 ,IO,OI,IO,OO,
+DEFUN("STRING-MATCH",int,fSstring_match,SI,2,4,0    ,IO,OI,IO,OO,
       "Match regexp PATTERN in STRING starting in string starting at START and ending at END.  Return -1 if match not found, otherwise return the start index  of the first matchs.  The variable *MATCH-DATA* will be set to a fixnum array of sufficient size to hold the matches, to be obtained with match-beginning and match-end. If it already contains such an array, then the contents of it will be over written.   ")
 DEF_ORDINARY("S-DATA",sSs_data,SI,"")
 DEF_ORDINARY("COMPILE",sLcompile,LISP,"")
@@ -373,6 +374,10 @@ DEF_ORDINARY("APPEND",sLappend,LISP,"")
 DEF_ORDINARY("NCONC",sLnconc,LISP,"")
 DEF_ORDINARY("APPLY",sLapply,LISP,"")
 DEF_ORDINARY("VECTOR",sLvector,LISP,"")
+DO_MARK:
+
+DO_INDENT:
+
 DEF_ORDINARY("UPCASE",sKupcase,KEYWORD,"")
 DEF_ORDINARY("DOWNCASE",sKdowncase,KEYWORD,"")
 DEF_ORDINARY("CAPITALIZE",sKcapitalize,KEYWORD,"")
@@ -402,50 +407,50 @@ DEFVAR("*PRINT-STRUCTURE*",sSAprint_structureA,SI,Cnil,"")
 DEF_ORDINARY("PRETTY-PRINT-FORMAT",sSpretty_print_format,SI,"")
 DEFVAR("*PRINT-NANS*",sSAprint_nansA,SI,Cnil,"")
 DEFUNO("FORMAT",object,fLformat,LISP
-   ,2,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,Lformat,"")
-DEFVAR("*INDENT-FORMATTED-OUTPUT*",sSAindent_formatted_outputA,SI,		((object)&Cnil_body) ,"")
+   ,2,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lformat,"")
+DEFVAR("*INDENT-FORMATTED-OUTPUT*",sSAindent_formatted_outputA,SI,((object)&Cnil_body) ,"")
 DEFUNO("DELETE-FILE",object,fLdelete_file,LISP
    ,1,1,0    ,OO,OO,OO,OO,Ldelete_file,"")
 DEFUNO("ERROR",object,fLerror,LISP
-   ,1,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lerror,"")
+   ,1,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,Lerror,"")
 DEFUNO("CERROR",object,fLcerror,LISP
-   ,2,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,Lcerror,"")
+   ,2,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,Lcerror,"")
 DEFUNO("IHS-TOP",object,fSihs_top,SI
-   ,0,0,0 ,OO,OO,OO,OO,siLihs_top,"")
+   ,0,0,0    ,OO,OO,OO,OO,siLihs_top,"")
 DEFUNO("IHS-FUN",object,fSihs_fun,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLihs_fun,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLihs_fun,"")
 DEFUNO("IHS-VS",object,fSihs_vs,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLihs_vs,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLihs_vs,"")
 DEFUNO("FRS-TOP",object,fSfrs_top,SI
-   ,0,0,0 ,OO,OO,OO,OO,siLfrs_top,"")
+   ,0,0,0    ,OO,OO,OO,OO,siLfrs_top,"")
 DEFUNO("FRS-VS",object,fSfrs_vs,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLfrs_vs,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLfrs_vs,"")
 DEFUNO("FRS-BDS",object,fSfrs_bds,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLfrs_bds,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLfrs_bds,"")
 DEFUNO("FRS-CLASS",object,fSfrs_class,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLfrs_class,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLfrs_class,"")
 DEFUNO("FRS-TAG",object,fSfrs_tag,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLfrs_tag,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLfrs_tag,"")
 DEFUNO("FRS-IHS",object,fSfrs_ihs,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLfrs_ihs,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLfrs_ihs,"")
 DEFUNO("BDS-TOP",object,fSbds_top,SI
-   ,0,0,0 ,OO,OO,OO,OO,siLbds_top,"")
+   ,0,0,0    ,OO,OO,OO,OO,siLbds_top,"")
 DEFUNO("BDS-VAR",object,fSbds_var,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLbds_var,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLbds_var,"")
 DEFUNO("BDS-VAL",object,fSbds_val,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLbds_val,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLbds_val,"")
 DEFUNO("VS-TOP",object,fSvs_top,SI
-   ,0,0,0 ,OO,OO,OO,OO,siLvs_top,"")
+   ,0,0,0    ,OO,OO,OO,OO,siLvs_top,"")
 DEFUNO("VS",object,fSvs,SI
-   ,1,1,0 ,OO,OO,OO,OO,siLvs,"")
+   ,1,1,0    ,OO,OO,OO,OO,siLvs,"")
 DEFUNO("SCH-FRS-BASE",object,fSsch_frs_base,SI
-   ,2,2,0 ,OO,OO,OO,OO,siLsch_frs_base,"")
+   ,2,2,0    ,OO,OO,OO,OO,siLsch_frs_base,"")
 DEFUNO("INTERNAL-SUPER-GO",object,fSinternal_super_go,SI
-   ,3,3,0 ,OO,OO,OO,OO,siLinternal_super_go,"")
+   ,3,3,0    ,OO,OO,OO,OO,siLinternal_super_go,"")
 DEF_ORDINARY("UNIVERSAL-ERROR-HANDLER",sSuniversal_error_handler,SI
 	     ,"Redefined in lisp, this is the function called by the internal error handling mechanism.  Args:  (error-name correctable function-name    continue-format-string error-format-string    &rest args)")
 DEFUNO("UNIVERSAL-ERROR-HANDLER",object,fSuniversal_error_handler,SI
-   ,5,((1<< 6 ) -1) ,0 ,OO,OO,OO,OO,
+   ,5,((1<< 6 ) -1) ,0    ,OO,OO,OO,OO,
        siLuniversal_error_handler,"")
 DEF_ORDINARY("TERMINAL-INTERRUPT",sSterminal_interrupt,SI,"")
 DEF_ORDINARY("WRONG-TYPE-ARGUMENT",sKwrong_type_argument,KEYWORD,"")
