@@ -85,9 +85,7 @@ sockaddr_in addr;
       if (0)
 	{
 	  fprintf(stderr,
-		  "\nAssigned automatic address to socket : "
-		  "port(%d), errno(%d), bind_rc(%d), "
-		  "iLastAddressUsed(%d), retries(%d)\n"
+  "\nAssigned automatic address to socket : port(%d), errno(%d), bind_rc(%d), iLastAddressUsed(%d), retries(%d)\n"
 		  , addr.sin_port, errno, rc, iLastAddressUsed, cRetry
 		  );
 	  fflush(stderr);
@@ -160,7 +158,8 @@ and returns (list* named_socket fd name1) when one is established")
 }
 
 object
-sock_hostname_to_hostid_list(char *host_name)
+sock_hostname_to_hostid_list(host_name)
+     char *host_name;
 {
   struct hostent *h;
   object addr_list = Cnil;
@@ -238,7 +237,8 @@ DEFUN("HOSTID-TO-HOSTNAME",object,fShostid_to_hostname,SI,
 }
 
 object
-sock_get_name(int s)
+sock_get_name(s)
+     int s;
 {
   struct sockaddr_in addr;
   int m = sizeof(addr);
@@ -499,3 +499,8 @@ connection_failure(s)
      char *s;
 {FEerror("Connect failure: ~s",1,make_simple_string(s));
 }
+
+
+#ifdef HAVE_X11
+#include "clxsocket.c"
+#endif
